@@ -19,8 +19,8 @@ async def test_register_check():
     checker = AppChecker()
     checker.register_check(mock_check_success)
 
-    assert len(checker.checks) == 1
-    assert checker.checks[0] == mock_check_success
+    assert len(checker._checks) == 1
+    assert checker._checks[0] == mock_check_success
 
 
 @pytest.mark.asyncio
@@ -30,8 +30,8 @@ async def test_run_checks_success():
 
     await checker.run_checks()
 
-    assert checker.success == 1
-    assert checker.failure == 0
+    assert checker._success == 1
+    assert checker._failure == 0
 
 
 @pytest.mark.asyncio
@@ -41,8 +41,8 @@ async def test_run_checks_failure():
 
     await checker.run_checks()
 
-    assert checker.success == 0
-    assert checker.failure == 1
+    assert checker._success == 0
+    assert checker._failure == 1
 
 
 @pytest.mark.asyncio
@@ -51,9 +51,9 @@ async def test_run_checks_exception_handling():
     checker.register_check(mock_check_with_exception)
 
     await checker.run_checks()
-    print(checker.failure)
-    assert checker.success == 0
-    assert checker.failure == 1
+
+    assert checker._success == 0
+    assert checker._failure == 1
 
 
 @pytest.mark.asyncio
@@ -64,5 +64,5 @@ async def test_multiple_checks():
 
     await checker.run_checks()
 
-    assert checker.success == 1
-    assert checker.failure == 1
+    assert checker._success == 1
+    assert checker._failure == 1
